=== modified file 'diff.py'
--- diff.py	2012-01-23 17:04:56 +0000
+++ diff.py	2012-01-23 21:47:33 +0000
@@ -5,22 +5,31 @@
 """
 
 __copyright__ = "Copyright 2005 Canonical Ltd."
-__author__    = "Scott James Remnant <scott@ubuntu.com>"
+__author__ = "Scott James Remnant <scott@ubuntu.com>"
 
 
 from cStringIO import StringIO
 
-from gi.repository import Gtk
-from gi.repository import Pango
 import os
 import re
 import sys
 import inspect
 try:
-    from xml.etree.ElementTree import Element, SubElement, tostring
+    from xml.etree.ElementTree import (
+        Element,
+        SubElement,
+        tostring,
+        )
+    Element, SubElement, tostring  # Hush PEP8 redefinition.
 except ImportError:
-    from elementtree.ElementTree import Element, SubElement, tostring
+    from elementtree.ElementTree import (
+        Element,
+        SubElement,
+        tostring,
+        )
 
+from gi.repository import Gtk
+from gi.repository import Pango
 try:
     from gi.repository import GtkSource
     have_gtksourceview = True
@@ -38,7 +47,7 @@
     osutils,
     urlutils,
     workingtree,
-)
+    )
 from bzrlib.diff import show_diff_trees
 from bzrlib.patches import parse_patches
 from bzrlib.trace import warning
@@ -112,9 +121,9 @@
         if style_scheme_name is not None:
             style_scheme_mgr = GtkSource.StyleSchemeManager()
             style_scheme_mgr.append_search_path(GEDIT_USER_STYLES_PATH)
-            
+
             style_scheme = style_scheme_mgr.get_scheme(style_scheme_name)
-            
+
             if style_scheme is not None:
                 buf.set_style_scheme(style_scheme)
 
@@ -128,7 +137,7 @@
         """
         scheme_manager = GtkSource.StyleSchemeManager()
         style_scheme = scheme_manager.get_scheme('colordiff')
-        
+
         # if style scheme not found, we'll generate it from colordiffrc
         # TODO: reload if colordiffrc has changed.
         if style_scheme is None:
@@ -148,7 +157,7 @@
             if not colors:
                 # ~/.colordiffrc does not exist
                 return
-            
+
             mapping = {
                 # map GtkSourceView2 scheme styles to colordiff names
                 # since GSV is richer, accept new names for extra bits,
@@ -159,7 +168,7 @@
                 'diff:file': ['file', 'diffstuff'],
                 'diff:special-case': ['specialcase', 'diffstuff'],
             }
-            
+
             converted_colors = {}
             for name, values in mapping.items():
                 color = None
@@ -170,7 +179,7 @@
                 if color is None:
                     continue
                 converted_colors[name] = color
-            
+
             # some xml magic to produce needed style scheme description
             e_style_scheme = Element('style-scheme')
             e_style_scheme.set('id', 'colordiff')
@@ -180,15 +189,19 @@
                 style = SubElement(e_style_scheme, 'style')
                 style.set('name', name)
                 style.set('foreground', '#%s' % color)
-            
+
             scheme_xml = tostring(e_style_scheme, 'UTF-8')
-            if not os.path.exists(os.path.expanduser('~/.local/share/gtksourceview-2.0/styles')):
-                os.makedirs(os.path.expanduser('~/.local/share/gtksourceview-2.0/styles'))
-            file(os.path.expanduser('~/.local/share/gtksourceview-2.0/styles/colordiff.xml'), 'w').write(scheme_xml)
-            
+            if not os.path.exists(os.path.expanduser(
+                '~/.local/share/gtksourceview-2.0/styles')):
+                os.makedirs(os.path.expanduser(
+                    '~/.local/share/gtksourceview-2.0/styles'))
+            file(os.path.expanduser(
+                '~/.local/share/gtksourceview-2.0/styles/colordiff.xml'),
+                'w').write(scheme_xml)
+
             scheme_manager.force_rescan()
             style_scheme = scheme_manager.get_scheme('colordiff')
-        
+
         buf.set_style_scheme(style_scheme)
 
     @staticmethod
@@ -216,13 +229,15 @@
 #        self.parent_tree.lock_read()
 #        self.rev_tree.lock_read()
 #        try:
-#            self.delta = iter_changes_to_status(self.parent_tree, self.rev_tree)
+#            self.delta = iter_changes_to_status(
+#               self.parent_tree, self.rev_tree)
 #            self.path_to_status = {}
 #            self.path_to_diff = {}
 #            source_inv = self.parent_tree.inventory
 #            target_inv = self.rev_tree.inventory
 #            for (file_id, real_path, change_type, display_path) in self.delta:
-#                self.path_to_status[real_path] = u'=== %s %s' % (change_type, display_path)
+#                self.path_to_status[real_path] = u'=== %s %s' % (
+#                    change_type, display_path)
 #                if change_type in ('modified', 'renamed and modified'):
 #                    source_ie = source_inv[file_id]
 #                    target_ie = target_inv[file_id]
@@ -230,7 +245,7 @@
 #                    source_ie.diff(internal_diff, *old path, *old_tree,
 #                                   *new_path, target_ie, self.rev_tree,
 #                                   sio)
-#                    self.path_to_diff[real_path] = 
+#                    self.path_to_diff[real_path] =
 #
 #        finally:
 #            self.rev_tree.unlock()
@@ -297,7 +312,7 @@
         self.pack1(scrollwin)
         if self.SHOW_WIDGETS:
             scrollwin.show()
-        
+
         self.model = Gtk.TreeStore(str, str)
         self.treeview = Gtk.TreeView(model=self.model)
         self.treeview.set_headers_visible(False)
@@ -353,28 +368,28 @@
         self.model.clear()
         delta = self.rev_tree.changes_from(self.parent_tree)
 
-        self.model.append(None, [ "Complete Diff", "" ])
+        self.model.append(None, ["Complete Diff", ""])
 
         if len(delta.added):
-            titer = self.model.append(None, [ "Added", None ])
+            titer = self.model.append(None, ["Added", None])
             for path, id, kind in delta.added:
-                self.model.append(titer, [ path, path ])
+                self.model.append(titer, [path, path])
 
         if len(delta.removed):
-            titer = self.model.append(None, [ "Removed", None ])
+            titer = self.model.append(None, ["Removed", None])
             for path, id, kind in delta.removed:
-                self.model.append(titer, [ path, path ])
+                self.model.append(titer, [path, path])
 
         if len(delta.renamed):
-            titer = self.model.append(None, [ "Renamed", None ])
+            titer = self.model.append(None, ["Renamed", None])
             for oldpath, newpath, id, kind, text_modified, meta_modified \
                     in delta.renamed:
-                self.model.append(titer, [ oldpath, newpath ])
+                self.model.append(titer, [oldpath, newpath])
 
         if len(delta.modified):
-            titer = self.model.append(None, [ "Modified", None ])
+            titer = self.model.append(None, ["Modified", None])
             for path, id, kind, text_modified, meta_modified in delta.modified:
-                self.model.append(titer, [ path, path ])
+                self.model.append(titer, [path, path])
 
         self.treeview.expand_all()
         self.diff_view.show_diff(None)
@@ -397,14 +412,14 @@
         (path, col) = self.treeview.get_cursor()
         if path is None:
             return
-        specific_files = [ self.model[path][1] ]
-        if specific_files == [ None ]:
+        specific_files = [self.model[path][1]]
+        if specific_files == [None]:
             return
-        elif specific_files == [ "" ]:
+        elif specific_files == [""]:
             specific_files = None
-        
+
         self.diff_view.show_diff(specific_files)
-    
+
     def _on_wraplines_toggled(self, widget=None, wrap=False):
         """Callback for when the wrap lines checkbutton is toggled"""
         if wrap or widget.get_active():
@@ -412,6 +427,7 @@
         else:
             self.diff_view.sourceview.set_wrap_mode(Gtk.WrapMode.NONE)
 
+
 class DiffWindow(Window):
     """Diff window.
 
@@ -446,8 +462,7 @@
         hbox = self._get_button_bar(operations)
         if hbox is not None:
             self.vbox.pack_start(hbox, False, True, 0)
-        
-    
+
     def _get_menu_bar(self):
         menubar = Gtk.MenuBar()
         # View menu
@@ -464,7 +479,7 @@
         menubar.append(mb_view)
         menubar.show()
         return menubar
-    
+
     def _get_button_bar(self, operations):
         """Return a button bar to use.
 

